@@ -5,7 +5,7 @@ use Storable qw(thaw freeze);
 use MIME::Base64;
 use Lemonldap::NG::Manager::Conf::Constants;
 
-our $VERSION = 0.44;
+our $VERSION = 0.45;
 our @ISA;
 
 sub new {
@@ -68,14 +68,12 @@ sub getConf {
     my $fields = $self->load( $args->{cfgNum}, $args->{fields} );
     my $conf;
     while ( my ( $k, $v ) = each(%$fields) ) {
-        my $tmp;
         $v =~ s/^'(.*)'$/$1/m;
-        eval "\$tmp = thaw(decode_base64('$v'))";
-        if ( $@ or not($tmp) ) {
-            $conf->{$k} = $v;
+       if( $k =~ /^(?:exportedVars|locationRules|groups|exportedHeaders|macros|globalStorageOptions)$/ ) {
+            $conf->{$k} = thaw(decode_base64($v));
         }
         else {
-            $conf->{$k} = $tmp;
+            $conf->{$k} = $v;
         }
     }
     return $conf;
@@ -179,6 +177,16 @@ http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
 
 Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
+=head1 BUG REPORT
+
+Use OW2 system to report bug or ask for features:
+L<http://forge.objectweb.org/tracker/?group_id=274>
+
+=head1 DOWNLOAD
+
+Lemonldap::NG is available at
+L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2006-2007 by Xavier Guimard
