@@ -2,7 +2,7 @@ package Lemonldap::NG::Manager::Help;
 
 use AutoLoader qw(AUTOLOAD);
 use UNIVERSAL qw(can);
-our $VERSION = '0.3';
+our $VERSION = '0.31';
 
 sub import {
     my ($caller_package) = caller;
@@ -56,7 +56,7 @@ evaluated one time in the authentication phase, and the result is stored in the
 <p> The last rule is a Perl regular expression (PCRE) that means 'search the
 word "group1" in the string "groups"'.</p>
 <p> The \$groups string joins all the groups where the user matchs the
-expression. The groups are separated by a space in the \$groups string.
+expression. The groups are separated by a space in the \$groups string.</p>
 EOT
 }
 
@@ -181,10 +181,10 @@ EOT
 
 sub help_domain_fr {
     print <<EOT;
-<h3>Domaine protg</h3>
+<h3>Domaine prot&eacute;g&eacute;</h3>
 <p> Indiquez ici le nom du domaine (ou du sous-domaine) contenant vos
-applications  protger.<br>
-ATTENTION : tous les htes virtuels protgs ainsi que le portail
+applications &agrave; prot&eacute;ger.<br>
+ATTENTION : tous les h&ocirc;tes virtuels prot&eacute;g&eacute;s ainsi que le portail
 d'authentification doivent se trouver dans ce domaine.
 EOT
 }
@@ -244,7 +244,7 @@ r&egrave;gles et les en-t&ecirc;tes HTTP export&eacute;s.</p>
 <p> <u>Note</u> : pour que le m&eacute;canisme d'authentification fonctionne, tous
 les h&ocirc;tes virtuels et le portail doivent se trouver dans le domaine d&eacute;clar&eacute;
 dans les param&egrave;tres g&eacute;n&eacute;raux ou <u>utiliser les modules CDA</u>
-<i>(Cross-Domain-Authentication)</i> qui gre la transmission de l'identifiant.</p>
+<i>(Cross-Domain-Authentication)</i> qui g&egrave;re la transmission de l'identifiant.</p>
 
 <h4> R&egrave;gles</h4>
 
@@ -399,9 +399,9 @@ EOT
 sub help_cookieName_fr {
     print <<EOT;
 <h3>Nom de cookie</h3>
-<p> Indiquez ici le nom du cookie ('lemonldap' par dfaut).<br>
+<p> Indiquez ici le nom du cookie ('lemonldap' par d&eacute;faut).<br>
 
-ATTENTION, tout changement ncessite le redmarrage de tous les serveurs Apache
-hbergeant des agents de protection Lemonldap::NG::Handler.</p>
+ATTENTION, tout changement n&eacute;cessite le red&eacute;marrage de tous les serveurs Apache
+h&eacute;bergeant des agents de protection Lemonldap::NG::Handler.</p>
 EOT
 }
